/* If this function is imported, you can import scss files using:

   @if not-imported("your-file") { @import "your-file"; }
*/
$imported-once-files: () !default;

@function not-imported($name) {
  $imported-once-files: $imported-once-files !global;
  $module_index: index($imported-once-files, $name);
  @if (($module_index == null) or ($module_index == false)) {
    $imported-once-files: append($imported-once-files, $name) !global;
    @return true;
  }
  @return false;
}