@if not-imported("import_once_func") { @import "import_once_func"; }
@if not-imported("framework") { @import "framework"; }

/* --- SLIDER --- */
/*#hero {
  height: 490px;
  overflow: hidden;

  > *,
  > * > *:first-child:last-child,
  > * > * > *:first-child:last-child {
    height: 100%;
  }

  .slick-slider-slide {
    height: 490px;
  }

  @media screen and (max-width: 599px) {
    height: 66vw;
    .slick-slider-slide {
      height: 66vw;
    }
  }
}

.slick-slider-container {
  .slick-slider-slide {
    .slide-content {
      @include centered-1200;
      height: 100%;

      .slide-text {
        position: absolute;
        left: 50%;
        top: 70%;
        font-size: font-size(50px);
        color: $color-text-alt-1;
        text-transform: uppercase;
        max-width: 50%;
        text-shadow: 1px 1px 5px #000;
        @include transform(translateY(-50%));
      }

    }
  }
}*/

/*
 ------ HERO ------
*/
#hero {
  .inside {
    overflow: hidden;
    -webkit-background-size: cover;
    background-size: cover;
    position: relative;
  }

  .logo-wrapper {
    position: absolute;
    left: 0;
    top: 0;
    width: 100%;
    height: 100%;

    .logo-holder {
      @include centered-1200;
      height: 100%;
    }
  }

  .hero-wrapper {
    min-height: 200px;
  }

  #logo {
    position: absolute;
    max-width: 35%;
    left: 0;
    top: 0;
    width: 215px;

    .-hide-logo &:not(.animated) {
      display: none;
    }

    &.animated {
      visibility: hidden;
      max-width: 45%;
      width: 390px;
      left: 50%;
      top: 70%;
      @include transform(translate(-50%, -50%));
    }

    svg {
      width: 100%;
      vertical-align: middle;
    }

    @include for-tablet {
      left: 50%;
      top: 50%;
      @include transform(translate(-50%, -50%));
    }
  }

  /*&:after {
    @include icon('\e900',40px);
    position: absolute;
    bottom: 30px;
    left: 50%;
    margin-left: -20px;
    color: $color-text;
  }*/

  .slick-slider-container {
    height: 545px;

    .home & {
      height: 860px;
    }

    .slick-slide {
      -webkit-box-sizing: border-box;
      -moz-box-sizing: border-box;
      box-sizing: border-box;
    }

    @include for-mobile {
      max-height: 50vh;

      .home & {
        max-height: calc(100vh - 50px);
      }
    }
  }

  .slick-slider-wrapper,
  .slick-list,
  .slick-track,
  .slick-slide,
  .slick-slide > div,
  .slick-slide > div > div,
  .slide-content {
    height: 100%;
  }

  .slide-content {
    @include centered-1200;

    .ce_image {
      height: 100%;

      &:first-child:last-child {
        .image_container {
          text-align: center;
        }
      }
    }
    .image_container {
      height: 100%;
      img {
        display: inline-block;
        max-height: 100%;
        width: auto;
      }
    }
  }
}