<?php

/**
 * TeamList for Contao
 *
 * Copyright (c) 2016 Benjamin Roth
 *
 * @license LGPL-3.0+
 */

$GLOBALS['TL_LANG']['REF']['divisions']['management'] = 'Management / Marketing';
$GLOBALS['TL_LANG']['REF']['divisions']['representatives'] = 'Sales representatives';
$GLOBALS['TL_LANG']['REF']['divisions']['office'] = 'Phone sales/office';
$GLOBALS['TL_LANG']['REF']['divisions']['sales'] = 'Sales';
$GLOBALS['TL_LANG']['REF']['divisions']['administration'] = 'Administration';
$GLOBALS['TL_LANG']['REF']['divisions']['accounting'] = 'Bookkeeping';
$GLOBALS['TL_LANG']['REF']['divisions']['tasting'] = 'Wine tasting';
$GLOBALS['TL_LANG']['REF']['divisions']['warehouse'] = 'Warehouse/dispatch';
$GLOBALS['TL_LANG']['REF']['divisions']['bottling'] = 'Filling technology';
$GLOBALS['TL_LANG']['REF']['divisions']['cellar'] = 'Cellar technology';
$GLOBALS['TL_LANG']['REF']['divisions']['logistics'] = 'Delivery';
$GLOBALS['TL_LANG']['REF']['divisions']['spirits'] = 'Premium schnapps';
$GLOBALS['TL_LANG']['REF']['divisions']['facility_management'] = 'Cleaning';

$GLOBALS['TL_LANG']['MSC']['divisions_filter'] = 'Department';
