.ico-wrapper {
  font-size: 1em;
  display: flex;
  align-items: center;
  justify-content: center;
  line-height: inherit;
  text-align: center;
  margin: 0;
}

.ico {
  display: inline-block;
  width: 1em;
  height: 1em;
  stroke-width: 0;
  stroke: currentColor;
  fill: currentColor;
}

svg {
  &.ico
  {
    vertical-align: middle;
  }
}
