<?php

return array(
	'label' => array(
		'Button',
		'Erzeugt einen oder mehrere Buttons als Standalone-Element',
	),
  'contentCategory' => 'links',
	'types' => array('content'),
	'standardFields' => array('cssID', 'headline'),
	'fields' => array(
    'linkAlign' => array(
      'label' => array('Horizontale Button-Ausrichtung', ''),
      'inputType' => 'select',
      'options' => array(
        '' => 'Linksbündig',
        '-align-center' => 'Zentriert',
        '-align-right' => 'Rechtsbündig',
      ),
      'eval' => array('tl_class' => 'w50'),
    ),
    'altLayout' => array(
      'label' => array('Style', ''),
      'inputType' => 'select',
      'options' => array(
        '' => 'Standard',
        '-style-brown' => 'Braun',
      ),
      'eval' => array('tl_class' => 'w50'),
    ),
    'boxes' => array(
      'label' => array('Buttons', ''),
      'elementLabel' => 'Button %s',
      'inputType' => 'list',
      'fields' => array(
        'linkLabel' => array(
          'label' => array('Button-Text', ''),
          'inputType' => 'text',
          'eval' => array('tl_class' => 'w50'),
        ),
        'linkUrl' => array(
          'label' => array('Button-URL', 'Beispiele: {{link_url::seitenalias}} (Alias, ID oder anderer Inserttag), http://example.com'),
          'inputType' => 'url',
          'eval' => array('tl_class' => 'w50'),
        ),
        'linkTitle' => array(
          'label' => array('Button-Title', ''),
          'inputType' => 'text',
          'eval' => array('tl_class' => 'w50'),
        ),
        'newWindow' => array(
          'label' => $GLOBALS['TL_LANG']['MSC']['target'],
          'inputType' => 'checkbox',
          'eval' => array('tl_class' => 'w50 m12'),
        ),
        'altLayout' => array(
          'label' => array('Style', ''),
          'inputType' => 'select',
          'options' => array(
            '' => 'Standard',
            '-style-brown' => 'Braun',
          ),
          'eval' => array('tl_class' => 'w50'),
        ),
        'attributes' => array(
          'label' => array('Benutzerdefinierte Button HTML-Attribute', ''),
          'inputType' => 'text',
          'eval' => array('tl_class' => 'clr w50'),
        ),
      ),
    ),
    'spacing' => array(
      'label' => array('Abstand'),
      'inputType' => 'group',
    ),
    'es_spacing' => array (
      'inputType' => 'standardField'
    ),
    'es_padding' => array (
      'inputType' => 'standardField'
    ),
  ),
);
