.jBox-TooltipDurbacher .jBox-container {
  border-radius: 4px;
  background: #C69749;
  color: #fff;
  box-shadow: 0 0 6px rgba(0, 0, 0, 0.4);
  font-size: 12px;
  text-transform: uppercase;
  letter-spacing: 0.1em;
  line-height: 1.3;
}

.jBox-TooltipDurbacher .jBox-pointer:after {
  background: #C69749;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
}

.jBox-TooltipDurbacher .jBox-closeButton {
  background: #C69749;
}

.jBox-TooltipDurbacher.jBox-closeButton-box:before {
  box-shadow: 0 0 6px rgba(0, 0, 0, 0.4);
}

.jBox-TooltipDurbacher.jBox-closeButton-box .jBox-closeButton path {
  fill: #ddd;
}

.jBox-TooltipDurbacher.jBox-closeButton-box .jBox-closeButton:hover path {
  fill: #fff;
}

.jBox-TooltipDurbacher.jBox-closeButton-box .jBox-closeButton:active path {
  fill: #bbb;
}
